@@ -1,23 +1,19 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
+# ------------------------------------------------------------------------------
+#  Copyright (c) 2021. Vignesh M
+#  This file parser.py, part of the attractors package is licensed under the MIT license.
+#  See LICENSE.md in the project root for license information.
+# ------------------------------------------------------------------------------
+
 import argparse
-import json
-from argparse import SUPPRESS
+import importlib.metadata as metadata
 
 import numpy as np
 
 from attractors.attractor import ATTRACTOR_PARAMS, Attractor
 
-try:
-    import importlib.metadata as metadata
-    import importlib.resources as pkg_resources
-except ImportError:
-    import importlib_resources as pkg_resources
-    import importlib_metadata as metadata
-
-from attractors import data
-
 
 def case_convert(snakecase_string):
     return snakecase_string.replace("_", " ").title().replace("Cnn", "CNN")
@@ -120,9 +116,7 @@ def cli():
     )
     optional.add_argument(
         "--rk2",
-        help=(
-            "method for 2nd order Runge-Kutta if specified to be used." " Default: heun"
-        ),
+        help="method for 2nd order Runge-Kutta if specified to be used. Default: heun",
         type=str,
         choices=["heun", "imp_poly", "ralston"],
         default="heun",
@@ -189,12 +183,8 @@ def cli():
     attractor = args.attractor
     if args.type == "multipoint":
         objs = [Attractor(attractor, kwargs=kwargs) for _ in range(args.n)]
-        for i in range(args.n):
-            objs[i].coord = (
-                np.array(objs[i].coord) + [np.random.normal(0, 0.01) for _ in range(3)]
-                if i != 0
-                else np.array(objs[i].coord)
-            )
+        for obj in objs[1:]:
+            obj.coord += np.random.normal(0, 0.01, size=3)
         itrs = []
         for obj in objs:
             func = getattr(obj, args.des)
