@@ -1,18 +1,30 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
+
+# ------------------------------------------------------------------------------
+#  Copyright (c) 2021. Vignesh M
+#  This file colortable.py, part of the attractors package is licensed under the MIT license.
+#  See LICENSE.md in the project root for license information.
+# ------------------------------------------------------------------------------
+
+"""Module that handles palettes and colormaps
+"""
+
+
+from typing import List
+
 import matplotlib.colors as mcolors
 import numpy as np
 
 
-def hex_to_rgb(value):
-    """
-    Converts hex to normalized rgb colours
+def hex_to_rgb(value: str) -> List[float]:
+    """Converts hex to normalized rgb colours
 
     Args:
         value (str): string of 6 characters representing a hex colour
 
     Returns:
-
+        list[float]: rgb color list
     """
     value = value.strip("#")
     lv = len(value)
@@ -22,24 +34,17 @@ def hex_to_rgb(value):
     return [v / 256 for v in rgb_vals]
 
 
-def get_continuous_cmap(hex_list, float_list=None):
-    """
-    Creates and returns a color map from a given hex list. If float_list
-    is not provided, colour map graduates linearly between each color
-    in hex_list. If float_list is provided, each color in hex_list is
-    mapped to the respective location in float_list.
+def get_continuous_cmap(hex_list: List[str]) -> mcolors.LinearSegmentedColormap:
+    """Creates and returns a color map from a given hex list.
 
     Args:
         hex_list (list[str]): list of hex code strings
-        float_list (list[float], optional): list of floats between 0 and 1,
-            same length as hex_list. Must start with 0 and end with 1. Defaults to None.
 
     Returns:
-        LinearSegmentedColormap: Colormap of given hex list.
+        matplotlib.colors.LinearSegmentedColormap: Colormap of given hex list.
     """
     rgb_list = [hex_to_rgb(i) for i in hex_list]
-    if not float_list:
-        float_list = list(np.linspace(0, 1, len(rgb_list)))
+    float_list = list(np.linspace(0, 1, len(rgb_list)))
 
     cdict = {}
     for num, col in enumerate(["red", "green", "blue"]):
